<?php

namespace App\Http\Controllers\User;

use Illuminate\Http\Request;
use App\Models\User\Language;
use App\Models\User\UserFeature;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Validator;
use Session;

class FeatureController extends Controller
{
    public function index(Request $request)
    {
        $lang = Language::where('code', $request->language)->where('user_id', Auth::guard('web')->user()->id)->first();
        $lang_id = $lang->id;
        $data['features'] = UserFeature::where('language_id', $lang_id)->where('user_id', Auth::guard('web')->user()->id)->orderBy('id', 'DESC')->get();
        $data['lang_id'] = $lang_id;
        return view('user.feature.index', $data);
    }
    public function edit($id)
    {
        $data['feature'] = UserFeature::findOrFail($id);
        return view('user.feature.edit', $data);
    }

    public function store(Request $request)
    {

        $rules = [
            'user_language_id' => 'required',
            'icon' => 'required',
            'title' => 'required|max:50',
            'text' => 'required|max:255',
            'serial_number' => 'required|integer',
        ];
        $messages = [
            'user_language_id.required' => 'The language field is required'
        ];
        $validator = Validator::make($request->all(), $rules, $messages);
        if ($validator->fails()) {
            $errmsgs = $validator->getMessageBag()->add('error', 'true');
            return response()->json($validator->errors());
        }



        if ($request->hasFile('icon')) {
            $file = $request->file('icon');
            $name = time() . $file->getClientOriginalName();
            $file->move('assets/front/img/user/feature/', $name);
        }
        $feature = new UserFeature;
        $feature->user_id = Auth::guard('web')->user()->id;
        $feature->icon = $name;
        $feature->language_id = $request->user_language_id;
        $feature->title = $request->title;
        $feature->text = $request->text;
        $feature->serial_number = $request->serial_number;
        $feature->save();
        Session::flash('success', 'Feature added successfully!');
        return "success";
    }
    public function update(Request $request)
    {
        $rules = [
            'title' => 'required|max:50',
            'text' => 'required|max:255',
            'serial_number' => 'required|integer',
        ];
        $messages = [];
        $validator = Validator::make($request->all(), $rules, $messages);
        if ($validator->fails()) {
            $errmsgs = $validator->getMessageBag()->add('error', 'true');
            return response()->json($validator->errors());
        }
        $feature = UserFeature::findOrFail($request->feature_id);
        if ($request->hasFile('icon')) {
            @unlink('assets/front/img/user/feature/' . $feature->icon);
            $file = $request->file('icon');
            $name = time() . $file->getClientOriginalName();
            $file->move('assets/front/img/user/feature/', $name);
        }

        
        if ($request->icon) {
            $feature->icon = $name;
        }
        $feature->title = $request->title;
        $feature->text = $request->text;
        $feature->serial_number = $request->serial_number;
        $feature->save();
        Session::flash('success', 'Feature updated successfully!');
        return back();
    }

    public function delete(Request $request)
    {
        $feature = UserFeature::findOrFail($request->feature_id);
        @unlink('assets/front/img/user/feature/' . $feature->icon);
        $feature->delete();
        Session::flash('success', 'Feature deleted successfully!');
        return back();
    }
}
